@@ -2,10 +2,11 @@ from numpy import zeros, array, dot, delete, append, unique
 from numpy import sin, arccos, arctan2
 from numpy.linalg import norm
 
-
+# Funciones para generar Mesh
 def LinearMesh(L,Ne,x0=0):
     '''
     Función que retorna nodos y conexiones para elementos finitos en 1D.
+
     Donde:
             L:      Longitud total de la barra.
             Ne:     Número de elementos a crear.
@@ -26,19 +27,66 @@ def LinearMesh(L,Ne,x0=0):
         Conex = conex
     return Mesh
 
+def founMesh(Lx1,Ly1,Lx2,Ly2,mz1):
+    '''
+    Función que genera Mesh tipo U para cimentaciones.
+
+    Donde:
+            Lx1, Ly1:       Longitud en X y Y de la zona convexa o interior.
+            Lx2, Ly2:       Longitud en X y Y de la zona exterior.
+    '''
+    coor = zeros((10000,2))
+    ni, nj = int(2*Lx2/mz1), int(Ly2/mz1)
+    k = 0
+    for j in range(nj+1):
+        for i in range(ni+1):
+            if (mz1*i-Lx2)>=-Lx1 and (mz1*i-Lx2)<=Lx1 and -mz1*j>=-Ly1:
+                continue
+            coor[k] = [mz1*i-Lx2,-mz1*j]
+            k = k + 1 
+    coor = coor[:k]
+    return coor
+
+def load_obj(fileName):
+    '''
+    Función que lee archivos tipo obj de blender para generar crear arreglos\
+    de coordenadas, elementos triangulares y rectangules (tri, quad).
+    '''
+    vertices, tri, quad = [], [], []
+    f = open(fileName)
+    for line in f:
+        if line[:2] == "v ":
+            vertex = line[2:].split()
+            vertices.append(vertex)
+        elif line[:2] == "f ":
+            face = line[2:].split()
+            if len(face) == 3:
+                tri.append(face)
+            else:
+                quad.append(face)
+    vertices = array(vertices, dtype=float)
+    tri = array(tri, dtype=int)
+    quad = array(quad, dtype=int)
+    f.close()
+
+    return vertices, tri, quad
+
+
+# Fuciones para crear condiciones de borde
 def BC_2Dx(X,dy,x,tipo,gdl,val):
     ''' Función que busca el nodo donde se aplicará las CB, especificando
-    una distancia Y y los tramos en x. (Utiliza un radio de búsqueda)
+    una distancia Y y el intervalo en x.
+
     Input:
-            dy:			Distancia Y donde se aplicaran CB
-            x:          intervalos de X donde se aplicaran CB [x1,x2]
+            dy:			Ordenada o distancia en y donde se aplicaran CB.
+            x:          Intervalo de X donde se aplicaran CB [x1,x2].
             X:          Matriz que contiene las coordenadas de los nodos.
     Output:
-            BC_data:    Matriz que define las condiciones de borde (la 
-                        columnas corresponden a: Nodo, Tipo, GDL y Valor)
+            BC_data:    Matriz que define las condiciones de borde (las \
+                        columnas corresponden a: Nodo, Tipo de CB, GDL y Valor)
     '''
     NN,k=len(X),0
-    BC_data = zeros((10000,4),dtype='float32')
+    BC_data = zeros((10000,4),dtype='float64')
     x1,x2 = x[0],x[1]
     k= 0
     for i in range(NN):
@@ -52,21 +100,22 @@ def BC_2Dx(X,dy,x,tipo,gdl,val):
         else: continue
     BC_data = BC_data[:k]
     n = len(BC_data)
-    for i in range(n): # si es Codicion Neumann
+    for i in range(n): # si es CB tipo Neumann distribuye val en los nodos
         if BC_data[i,1]==0: BC_data[i,3] = val/n
     print('Se crearon %i condiciones de Borde.'%n)
     return BC_data
 
 def BC_2Dy(X,dx,y,tipo,gdl,val):
     ''' Función que busca el nodo donde se aplicará las CB, especificando
-    una distancia Y y los tramos en x. (Utiliza un radio de búsqueda)
+    una distancia X y el intervalo en y.
+
     Input:
-            dx:			Distancia X donde se aplicaran CB
-            y:          intervalos de Y donde se aplicaran CB [y1,y2]
+            dx:			Ordenada o distancia en x donde se aplicaran CB.
+            y:          Intervalo de Y donde se aplicaran CB [y1,y2].
             X:          Matriz que contiene las coordenadas de los nodos.
     Output:
-            BC_data:    Matriz que define las condiciones de borde (la 
-                        columnas corresponden a: Nodo, Tipo, GDL y Valor)
+            BC_data:    Matriz que define las condiciones de borde (las \
+                        columnas corresponden a: Nodo, Tipo de CB, GDL y Valor)
     '''
     NN,k=len(X),0
     BC_data = zeros((10000,4),dtype='float32')
@@ -82,15 +131,18 @@ def BC_2Dy(X,dx,y,tipo,gdl,val):
         else: continue
     BC_data = BC_data[:k]
     n = len(BC_data)
-    for i in range(n): # si es Codicion Neumann
+    for i in range(n): # si es CB tipo Neumann distribuye val en los nodos
         if BC_data[i,1]==0: BC_data[i,3] = val/n
     print('Se crearon %i condiciones de Borde.'%n)
     return BC_data
 
 
-
 # Funciones para delaunay triangulation
 def circumcenter(tri):
+    '''
+    Función que encuentra el  circumcentro (xo,yo) y su radio ro \
+    dada tres coordenadas.
+    '''
     s = zeros(3)
     pts = [2,0,1,2,0]
     for i in range(1,4):
@@ -103,6 +155,16 @@ def circumcenter(tri):
     return xo,yo,r
 
 def getPolygon(xyo,elems,xd):
+    '''
+    Función que genera un poligono uniendo elementos triangulares.
+
+    Donde:
+            xyo:        Circumcentro
+            elems:      Arreglo relacionados al circumcentro que contiene \
+                        la conexión de los elementos a unir.
+            xd:         Arreglo que contiene las coordenadas de todos los nodos.  
+            pol:        Arreglo que contiene los nodos del polígono generado.  
+    '''
     pol = elems[0]
     for e in elems[1:]:
         pol = append(pol,e)
@@ -116,6 +178,9 @@ def getPolygon(xyo,elems,xd):
     return append(pol,pol[0])
 
 def updateMesh(xyo,xd,elems,selec):
+    '''
+    Función que actualiza el Mesh (agrega elementos y nodos).
+    '''
     local_elems = elems[selec]
     if len(local_elems)==0: print('*'*20+'No triangle found!'+'*'*20)
     else: pol = getPolygon(xyo,local_elems,xd)
@@ -127,6 +192,11 @@ def updateMesh(xyo,xd,elems,selec):
     return xd,elems2
 
 def delaunay(coor):
+    '''
+    Función que genera un Mesh uniforme basado en la triangulación de Delaunay \
+    a partir de coordenadas.
+    '''
+    print("Triangulación de Delaunay ...")
     maxX,maxY = max(coor[:,0]),max(coor[:,1])
     minX,minY = min(coor[:,0]),min(coor[:,1])
 
@@ -162,45 +232,9 @@ def delaunay(coor):
                 selec.append(ie)
                 break
     cnx =delete(cnx, selec, axis=0)-4
+    print("Terminó la triangulación.")
     return cnx
 
 
-# Funcion que genera nodos para analizar cimentaciones
-
-def founMesh(x1,y1,x2,y2,mz1):
-    coor = zeros((10000,2))
-    ni, nj = int(2*x2/mz1), int(y2/mz1)
-    k = 0
-    for j in range(nj+1):
-        for i in range(ni+1):
-            if (mz1*i-x2)>=-x1 and (mz1*i-x2)<=x1 and -mz1*j>=-y1:
-                continue
-            coor[k] = [mz1*i-x2,-mz1*j]
-            k = k + 1 
-    coor = coor[:k]
-    return coor
 
 
-# Funcion que lee archivos obj de render
-def load_obj(fileName):
-    vertices = []
-    tri = []
-    quad = []
-
-    f = open(fileName)
-    for line in f:
-        if line[:2] == "v ":
-            vertex = line[2:].split()
-            vertices.append(vertex)
-        elif line[:2] == "f ":
-            face = line[2:].split()
-            if len(face) == 3:
-                tri.append(face)
-            else:
-                quad.append(face)
-    vertices = array(vertices, dtype=float)
-    tri = array(tri, dtype=int)
-    quad = array(quad, dtype=int)
-    f.close()
-
-    return vertices, tri, quad
